@@ -7,7 +7,10 @@
  #include <config.h>
 #endif
 
+#ifndef WIN32
 #include <unistd.h>
+#include <utime.h>
+#endif
 #include <stdlib.h>
 #include <stdint.h>             /* uint32_t */
 #include <sys/types.h>          /* size_t */
@@ -15,11 +18,25 @@
 #include <string.h>
 #include <limits.h>
 #include <stdio.h>
-#include <utime.h>
 
 #include <glib.h>
 #include <glib/gstdio.h>
 
+#ifdef WIN32
+#define strcasecmp _stricmp
+#define strncasecmp _strnicmp
+
+#if !defined S_ISDIR
+#define S_ISDIR(m) (((m) & S_IFMT) == S_IFDIR)
+#endif
+
+#if !defined(S_ISREG) && defined(S_IFMT) && defined(S_IFREG)
+#define S_ISREG(m) (((m) & S_IFMT) == S_IFREG)
+#endif
+
+#define F_OK 0
+#endif
+
 #define EMPTY_SHA1  "0000000000000000000000000000000000000000"
 
 #define CURRENT_ENC_VERSION 3
@@ -39,16 +56,4 @@
 
 #define SEAF_PATH_MAX 4096
 
-#ifndef ccnet_warning
-#define ccnet_warning(fmt, ...) g_warning("%s(%d): " fmt, __FILE__, __LINE__, ##__VA_ARGS__)
-#endif
-
-#ifndef ccnet_error
-#define ccnet_error(fmt, ...)   g_error("%s(%d): " fmt, __FILE__, __LINE__, ##__VA_ARGS__)
-#endif
-
-#ifndef ccnet_message
-#define ccnet_message(fmt, ...) g_message("%s(%d): " fmt, __FILE__, __LINE__, ##__VA_ARGS__)
-#endif
-
 #endif
