@@ -92,6 +92,11 @@ register_rpc_service ()
                                      "seafile_sync_error_id_to_str",
                                      searpc_signature_string__int());
 
+    searpc_server_register_function ("seafile-rpcserver",
+                                     seafile_add_del_confirmation,
+                                     "seafile_add_del_confirmation",
+                                     searpc_signature_int__string_int());
+
     searpc_server_register_function ("seafile-rpcserver",
                                      seafile_get_config,
                                      "seafile_get_config",
@@ -389,6 +394,7 @@ main (int argc, char **argv)
     char *seafile_dir = NULL;
     char *worktree_dir = NULL;
     char *logfile = NULL;
+    char *eventfile = NULL;
     const char *debug_str = NULL;
     int daemon_mode = 0;
     char *ccnet_debug_level_str = "info";
@@ -496,6 +502,14 @@ main (int argc, char **argv)
         exit (1);
     }
 
+    eventfile = g_build_filename (config_dir, "logs", "events.log", NULL);
+    if (seafile_event_log_init (eventfile) < 0) {
+        seaf_warning ("Failed to init event log.\n");
+        exit (1);
+    }
+
+    seafile_event_message("Starting record seafile events.\n");
+
     /* init seafile */
     if (seafile_dir == NULL)
         seafile_dir = g_build_filename (config_dir, "seafile-data", NULL);
@@ -516,6 +530,7 @@ main (int argc, char **argv)
     g_free (seafile_dir);
     g_free (worktree_dir);
     g_free (logfile);
+    g_free (eventfile);
 
 #ifndef WIN32
     set_signal_handlers (seaf);
