@@ -168,6 +168,9 @@ seafile_session_config_set_int (SeafileSession *session,
     if (g_strcmp0(key, KEY_PROXY_PORT) == 0) {
         session->http_proxy_port = value;
     }
+    if (g_strcmp0(key, KEY_DELETE_CONFIRM_THRESHOLD) == 0) {
+        session->delete_confirm_threshold = value;
+    }
 
     return 0;
 }
